@@ -16,7 +16,6 @@ class ZafiraClient:
     STATUS_PATH = "/api/status"
     REFRESH_TOKEN_PATH = "/api/iam/v1/auth/refresh"
     LOGIN_PATH = "/api/auth/login"
-    PROFILE_PATH = "/api/users/profile"
     TEST_SUITES_PATH = "/api/tests/suites"
     TEST_CASES_PATH = "/api/tests/cases"
     JOBS_PATH = "/api/jobs"
@@ -170,13 +169,6 @@ class ZafiraClient:
         return self.api.send_put(ZafiraClient.USERS_PATH, user, headers=self.init_auth_headers(),
                                  default_err_msg="Unable to create user")
 
-    def get_user_profile(self, username=None):
-        endpoint = ZafiraClient.PROFILE_PATH
-        if username:
-            endpoint += "?username=" + username
-        return self.api.send_get(endpoint, headers=self.init_auth_headers(),
-                                 default_err_msg="Unable to authorize user")
-
     def get_user_or_anonymous_if_not_found(self, username):
         try:
             return self.get_user_profile(username)
