@@ -3,12 +3,10 @@ import time
 import pytest
 import uuid
 
-from .context import Context, Parameter
 from .resource_constants import TestStatus
 
 
 class BaseZafiraListener:
-    logger = logging.getLogger('zafira')
 
     def __init__(self, state):
         self.state = state
@@ -25,11 +23,11 @@ class BaseZafiraListener:
                 if self.state.is_enabled:
                     self.state.refresh_token = self.state.zc.refresh_token(self.state.access_token).json()
                     self.state.zc.auth_token = self.state.refresh_token['authToken']
-                    self.logger.info("Zafira is " + "available" if self.state.is_enabled else "unavailable")
+                    logging.info("Zafira is " + "available" if self.state.is_enabled else "unavailable")
 
             enabled = self.state.is_enabled
         except Exception as e:
-            self.logger.error("Unable to initialize connector: {}".format(e))
+            logging.error("Unable to initialize connector: {}".format(e))
         return enabled
 
     def compose_package_name(self, path_entries_list):
@@ -44,7 +42,7 @@ class BaseZafiraListener:
         try:
             self.state.zc.add_test_artifact_to_test(test["id"], artifact_link, artifact_name, expires_in)
         except Exception as e:
-            self.logger.error("Unable to add artifact to test correctly: {}".format(e))
+            logging.error("Unable to add artifact to test correctly: {}".format(e))
 
     def on_test_success(self):
         """
@@ -71,7 +69,7 @@ class BaseZafiraListener:
             work_items.append(work_item if len(work_item) < self.state.MAX_LENGTH_OF_WORKITEM else 'Skipped')
             self.state.zc.create_test_work_items(test_id, work_items)
         except Exception as e:
-            self.logger.error("Unable to add work item: {}".format(e))
+            logging.error("Unable to add work item: {}".format(e))
 
 
 class PyTestZafiraListener(BaseZafiraListener):
@@ -94,7 +92,6 @@ class PyTestZafiraListener(BaseZafiraListener):
         if not self.initialized:
             return
         try:
-            self.state.user = self.state.zc.get_user_profile().json()
             self.state.test_suite = self.state.zc.create_test_suite(
                 self.state.user["id"], self.state.suite_name, 'filename'
             ).json()
@@ -114,7 +111,7 @@ class PyTestZafiraListener(BaseZafiraListener):
             self.state.ci_run_id = self.state.test_run.get('ciRunId')
         except Exception as e:
             self.state.is_enabled = False
-            self.logger.error("Undefined error during test run registration! {}".format(e))
+            logging.error("Undefined error during test run registration! {}".format(e))
 
     @pytest.hookimpl
     def pytest_runtest_setup(self, item):
@@ -149,7 +146,7 @@ class PyTestZafiraListener(BaseZafiraListener):
                 work_items
             ).json()
         except Exception as e:
-            self.logger.error("Undefined error during test case/method start! {}".format(e))
+            logging.error("Undefined error during test case/method start! {}".format(e))
 
     @pytest.hookimpl
     def pytest_runtest_teardown(self, item):
@@ -177,7 +174,7 @@ class PyTestZafiraListener(BaseZafiraListener):
 
             self.state.zc.finish_test(self.state.test)
         except Exception as e:
-            self.logger.error("Unable to finish test run correctly: {}".format(e))
+            logging.error("Unable to finish test run correctly: {}".format(e))
 
     @pytest.hookimpl
     def pytest_runtest_logreport(self, report):
@@ -209,7 +206,7 @@ class PyTestZafiraListener(BaseZafiraListener):
                     self.state.artifact_expires_in_default_time
                 )
         except Exception as e:
-            self.logger.error("Unable to finish test correctly: {}".format(e))
+            logging.error("Unable to finish test correctly: {}".format(e))
 
     @pytest.hookimpl
     def pytest_sessionfinish(self, session, exitstatus):
@@ -221,7 +218,7 @@ class PyTestZafiraListener(BaseZafiraListener):
         try:
             self.state.zc.finish_test_run(self.state.test_run["id"])
         except Exception as e:
-            self.logger.error("Unable to finish test run correctly: {}".format(e))
+            logging.error("Unable to finish test run correctly: {}".format(e))
 
     def on_test_success(self):
         self.state.test['status'] = TestStatus.PASSED.value
